@@ -10,22 +10,22 @@ SEXP R_point_in_polygon_sp(const SEXP px, const SEXP py, const SEXP polx,
 	POLYGON pol;
 	SEXP ret, px1, py1, polx1, poly1;
 
-	if (NAMED(px)) {
+	if (MAYBE_REFERENCED(px)) {
 		PROTECT(px1 = duplicate(px));
 		pc++;
 	} else
 		px1 = px;
-	if (NAMED(py)) {
+	if (MAYBE_REFERENCED(py)) {
 		PROTECT(py1 = duplicate(py));
 		pc++;
 	} else
 		py1 = py;
-	if (NAMED(polx)) {
+	if (MAYBE_REFERENCED(polx)) {
 		PROTECT(polx1 = duplicate(polx));
 		pc++;
 	} else
 		polx1 = polx;
-	if (NAMED(poly)) {
+	if (MAYBE_REFERENCED(poly)) {
 		PROTECT(poly1 = duplicate(poly));
 		pc++;
 	} else
